@@ -62,10 +62,11 @@ def _reset_and_update_link_vol_based_on_columns(column_pool,
         for col in cv.get_columns():
             path_vol = col.get_volume()
             for i in col.links:
-                pce_ratio = 1
+                # 04/10/22, remove it from now on as it is not in need
+                # pce_ratio = 1 and path_vol * pce_ratio
                 links[i].increase_period_flow_vol(
                     tau,
-                    path_vol * pce_ratio
+                    path_vol
                 )
                 # Peiheng, 04/05/21, not needed for the current implementation
                 # links[i].increase_period_agent_vol(
@@ -74,7 +75,7 @@ def _reset_and_update_link_vol_based_on_columns(column_pool,
                 #     path_vol
                 # )
 
-            if not cv.is_route_fixed() and is_path_vol_self_reducing:
+            if is_path_vol_self_reducing and not cv.is_route_fixed():
                 col.vol *= iter_num / (iter_num + 1)
 
 
@@ -106,21 +107,12 @@ def _update_column_gradient_cost_and_flow(column_pool,
         least_gradient_cost_path_id = -1
 
         for col in cv.get_columns():
-            path_toll = 0
             path_gradient_cost = 0
-            path_travel_time = 0
             # i is link sequence no
-            for i in col.get_links():
-                path_toll += links[i].get_toll()
-                path_travel_time += (
-                    links[i].travel_time_by_period[tau]
-                )
-                path_gradient_cost += (
-                    links[i].get_generalized_cost(tau, vot)
-                )
+            path_gradient_cost = sum(
+                links[i].get_generalized_cost(tau, vot) for i in col.links
+            )
 
-            col.set_toll(path_toll)
-            col.set_travel_time(path_travel_time)
             col.set_gradient_cost(path_gradient_cost)
 
             if column_num == 1:
@@ -166,8 +158,9 @@ def _update_column_gradient_cost_and_flow(column_pool,
                      * col.get_gradient_cost_rel_diff())
                 )
 
-                col.set_switch_volume(previous_path_vol - col.get_volume())
-                total_switched_out_path_vol += col.get_switch_volume()
+                total_switched_out_path_vol += (
+                    previous_path_vol - col.get_volume()
+                )
 
         if least_gradient_cost_path_id != -1:
             col = cv.get_column(least_gradient_cost_path_id)
@@ -252,6 +245,9 @@ def _backtrace_shortest_path_tree(orig_node_no,
 
         existing = False
         for col in cv.get_columns():
+            if col.get_distance() != dist:
+                continue
+
             if col.get_links() == link_path:
                 col.increase_volume(vol)
                 existing = True
@@ -267,7 +263,8 @@ def _backtrace_shortest_path_tree(orig_node_no,
             cv.add_new_column(col)
 
 
-def _update_column_travel_time(column_pool, links):
+def _update_column_attributes(column_pool, links):
+    """ update toll and travel time for each column """
     for k, cv in column_pool.items():
         # k = (at, dp, oz, dz)
         dp = k[1]
@@ -278,6 +275,11 @@ def _update_column_travel_time(column_pool, links):
             )
             col.set_travel_time(travel_time)
 
+            path_toll = sum(
+                links[j].get_toll() for j in col.links
+            )
+            col.set_toll(path_toll)
+
 
 def _generate(spn, column_pool, iter_num):
     for node_id in spn.get_orig_nodes():
@@ -373,7 +375,7 @@ def perform_column_generation(column_gen_num, column_update_num, ui):
 
     _update_link_travel_time_and_cost(links)
 
-    _update_column_travel_time(column_pool, links)
+    _update_column_attributes(column_pool, links)
 
 
 def update_links_using_columns(network):
